import Sound from 'react-native-sound';

const singleton = (() => {
  let instance;
  const soundInstance = {};

  const init = () => {
    Sound.setCategory('Playback', true);

    return {
      preload: (file) => {
        const sounddata = new Sound(file, null, (error) => {
          if (error) {
            return;
          }
          soundInstance[file] = sounddata;
        });
      },
      play: (file, path) => {
        let data = soundInstance[path];
        if (!data) {
          data = new Sound(file, null, (error) => {
            if (error) {
              return;
            }
            soundInstance[path] = data;
            // data.play();
            return data;
          });
        } else {
          // data.play();
          return data;
        }
      },
      pause: (file) => {
        const data = soundInstance[file];
        if (data) {
          data.pause();
        }
      },
      stop: (file) => {
        const data = soundInstance[file];
        if (data) {
          data.stop();
        }
      },
      destroy: () => {
        const keys = Object.keys(soundInstance);

        for (let index = 0; index < keys.length; index += 1) {
          const file = keys[index];
          const data = soundInstance[file];
          if (data) {
            data.stop();
            data.release();
            delete soundInstance[file];
          }
        }
      },

      getSoundAll: () => {
        return soundInstance;
      },

      getDataSound: (file) => {
        const data = soundInstance[file];
        return data;
      },
    };
  };

  return {
    getInstance: () => {
      if (!instance) {
        instance = init();
      }
      return instance;
    },
  };
})();

export default singleton.getInstance();
