import Sound from 'react-native-sound';

Sound.setCategory('Playback', false);

let playingSounds = [];

class SoundPlayer {
  static stopCurrentPlayingSounds() {
    for (let sound of playingSounds) {
      sound.stop(() => {
        sound.release();
      });
    }
    playingSounds = [];
  }

  static play(soundKey, shouldStopOther = true) {
    if (shouldStopOther) {
      SoundPlayer.stopCurrentPlayingSounds();
    }

    return new Promise((resolve, reject) => {
      const sound = new Sound(soundKey.value, null, (error) => {
        if (error) {
          console.warn('Failed to load', soundKey, error);
          reject(new Error('Failed to load ' + soundKey));
          return;
        }

        playingSounds.push(sound);

        sound.play((success) => {
          sound.release();

          if (success) {
            resolve(soundKey);
            return;
          }

          sound.reset();
          console.warn('Failed to play', soundKey, sound._key);
          reject(new Error('Failed to play ' + soundKey));
        });
      }); // new Sound
    }); // new Promise
  }
}

export default SoundPlayer;
