import React, {Component} from 'react';
import {
  PermissionsAndroid,
  Platform,
  Image,
  StyleSheet,
  Alert,
  Text,
  View,
  TouchableOpacity,
} from 'react-native';
import Slider from '@react-native-community/slider';
import {Player, Recorder} from '@react-native-community/audio-toolkit';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import {connect} from 'react-redux';
import {
  REQUEST_SUBMIT_USES_ANSWER,
  REQUEST_UPLOAD_RECORD,
} from '../../redux/actions';
import * as colors from '../../assets/colors';
import ic_play_record from '../../assets/images/ic_play_record.png';
import ic_play_disable from '../../assets/images/ic_play_disable.png';
import ic_pause_record from '../../assets/images/ic_pause_record.png';
import {setDuration} from '../../common/helper';

class AudioRecording extends Component {
  constructor(props) {
    super(props);
    this.state = {
      playPauseButton: 'Play',
      recordButton: 'Record',
      isRecording: false,
      loopButtonStatus: false,
      progress: 0,
      error: null,
      recordTime: 0,
    };
  }

  componentWillMount() {
    this.player = null;
    this.recorder = null;
    this.lastSeek = 0;
  }

  componentDidMount() {}

  componentWillUnmount() {
    clearInterval(this._progressInterval);
    clearInterval(this.recordTimer);
  }

  _shouldUpdateProgressBar() {
    return Date.now() - this.lastSeek > 200;
  }

  filename = () => {
    const {item} = this.props;
    return `record_${item.test_id}_${item.id}.mp4`;
  };

  _updateState() {
    this.setState({
      playPauseButton: this.player && this.player.isPlaying ? 'Pause' : 'Play',
      recordButton:
        this.recorder && this.recorder.isRecording ? 'Stop' : 'Record',
      recordTime: 0,
    });
  }

  isAnswerExisted = () => {
    const user_answer = this.props.submitData;
    const {item} = this.props;
    const answerExisted = user_answer.find(
      (answer) => answer.question_id === item.id,
    );
    if (answerExisted) {
      if (answerExisted.player) {
        this.player = answerExisted.player;
        return true;
      } else {
        return false;
      }
    }
    return false;
  };

  setTimSeek = () => {
    this._progressInterval = setInterval(() => {
      if (this.player && this._shouldUpdateProgressBar()) {
        let currentProgress =
          Math.max(0, this.player.currentTime) / this.player.duration;
        if (isNaN(currentProgress)) {
          currentProgress = 0;
        }
        this.setState({progress: currentProgress});
        if (currentProgress === 0) {
          clearInterval(this._progressInterval);
          this.props.onPauseAudio(false);
        }
      }
    }, 100);
  };

  _playPause() {
    if (this.isAnswerExisted()) {
      this.player.playPause((err, paused) => {
        console.log('tienvt 81', err, paused);
        if (paused) {
          clearInterval(this._progressInterval);
          this.setState({playPauseButton: 'Play'});
          this.props.onPauseAudio(false);
        } else {
          this.setTimSeek();
          this.setState({playPauseButton: 'Pause'});
          this.props.onPauseAudio(true);
        }
      });
    } else {
      Alert.alert('Bạn chưa ghi âm câu trả lời');
    }
  }

  _stop() {
    if (this.player) {
      clearInterval(this._progressInterval);
      this.player.stop(() => {
        this.setState({playPauseButton: 'Play'});
      });
    }
  }

  _seek(percentage) {
    if (!this.player) {
      return;
    }

    this.lastSeek = Date.now();

    let position = percentage * this.player.duration;

    this.player.seek(position, () => {
      this._updateState();
    });
  }

  _reloadPlayer() {
    // if (this.player) {
    //   this.player.destroy();
    // }
    this.player = new Player(this.filename(), {
      autoDestroy: false,
    }).prepare((err) => {
      if (err) {
        console.log('error at _reloadPlayer():');
        console.log(err);
      } else {
        this.player.looping = this.state.loopButtonStatus;
      }

      this._updateState();

      this.player.on('ended', () => {
        this._updateState();
      });
      this.player.on('pause', () => {
        this._updateState();
      });
    });
    const {item, dispatch} = this.props;
    const user_choose = {value: ''};
    const data_answer = {
      player: this.player,
      record: this.recorder,
      // section_id: item.section_id,
      // section_tag: item.section_tag,
      question_id: item.id,
      // question_configuration: JSON.parse(item.configurations),
      user_answer: user_choose,
      type: item.type,
    };
    dispatch({
      type: REQUEST_SUBMIT_USES_ANSWER,
      payload: {data: data_answer},
    });
    dispatch({type: REQUEST_UPLOAD_RECORD, payload: data_answer});
  }

  _reloadRecorder() {
    if (this.state.recordButton === 'Stop') {
      // this.props.onPauseAudio();
      this.recorder.stop(() => {
        this._reloadPlayer();
        // this.setState({recordButton: 'Record'});
      });
    } else {
      // this.props.onPauseAudio();
      if (this.recorder) {
        this.recorder.destroy(() => {
          this.newRecord();
        });
      } else {
        this.newRecord();
      }
    }
  }

  newRecord = () => {
    this.recordStartTime = Date.now();
    this.recorder = new Recorder(this.filename(), {
      bitrate: 256000,
      channels: 2,
      sampleRate: 44100,
      format: 'mp4',
      quality: 'medium',
    }).record((res) => {
      this.recordTimer = setInterval(() => {
        this.setState({recordTime: Date.now() - this.recordStartTime});
      }, 200);
    });
    this.setState({recordButton: 'Stop'});
  };

  _toggleRecord() {
    clearInterval(this.recordTimer);
    clearInterval(this._progressInterval);
    if (this.player) {
      this.player.destroy();
    }
    const {recordButton} = this.state;
    this.props.onPauseAudio(recordButton === 'Record' ? true : false);
    let recordAudioRequest;
    if (Platform.OS === 'android') {
      recordAudioRequest = this._requestRecordAudioPermission();
    } else {
      recordAudioRequest = new Promise(function (resolve, reject) {
        resolve(true);
      });
    }

    recordAudioRequest.then((hasPermission) => {
      if (!hasPermission) {
        this.setState({
          error: 'Record Audio Permission was denied',
        });
        return;
      }
      this._reloadRecorder();
    });
  }

  async _requestRecordAudioPermission() {
    try {
      const granted = await PermissionsAndroid.request(
        PermissionsAndroid.PERMISSIONS.RECORD_AUDIO,
        {
          title: 'Microphone Permission',
          message: 'Application needs access to your microphone to record.',
          buttonNeutral: 'Ask Me Later',
          buttonNegative: 'Cancel',
          buttonPositive: 'OK',
        },
      );
      if (granted === PermissionsAndroid.RESULTS.GRANTED) {
        return true;
      } else {
        return false;
      }
    } catch (err) {
      console.error(err);
      return false;
    }
  }

  _toggleLooping(value) {
    this.setState({
      loopButtonStatus: value,
    });
    if (this.player) {
      this.player.looping = value;
    }
  }

  disablePlay = () => {
    if (this.state.recordButton === 'Stop') {
      return true;
    } else {
      if (!this.isAnswerExisted()) {
        return true;
      } else {
        return false;
      }
    }
  };

  render() {
    const {recordTime} = this.state;
    return (
      <View style={styles.content}>
        <View>
          {this.state.recordButton === 'Record' ? (
            <TouchableOpacity
              disabled={this.props.isFinish}
              onPress={() => this._toggleRecord()}
              style={styles.buttonRecord}>
              <FontAwesome name="microphone" size={35} color="#fff" />
            </TouchableOpacity>
          ) : (
            <TouchableOpacity
              onPress={() => this._toggleRecord()}
              style={styles.buttonRecord}>
              <FontAwesome name="square" size={25} color="#fff" />
            </TouchableOpacity>
          )}
          <Text style={styles.title}>
            {recordTime > 0 ? setDuration(recordTime) : 'Record'}
          </Text>
        </View>
        <View style={styles.viewSlide}>
          <Slider
            step={0.0001}
            disabled={this.disablePlay()}
            onValueChange={(percentage) => this._seek(percentage)}
            value={this.state.progress}
            minimumTrackTintColor={colors.color_orange}
            maximumTrackTintColor="#FFFFFF"
          />
          {this.state.playPauseButton === 'Pause' ? (
            <TouchableOpacity
              onPress={() => this._playPause()}
              style={styles.btnPlay}>
              <Image
                source={ic_pause_record}
                resizeMode="contain"
                style={styles.btnControl}
              />
            </TouchableOpacity>
          ) : (
            <TouchableOpacity
              onPress={() => this._playPause()}
              disabled={this.disablePlay()}
              style={styles.btnPlay}>
              <Image
                source={!this.disablePlay() ? ic_play_record : ic_play_disable}
                resizeMode="contain"
                style={styles.btnControl}
              />
            </TouchableOpacity>
          )}
        </View>
      </View>
    );
  }
}

function mapStateToProps(state) {
  return {
    submitData: state.submitData.user_answer,
  };
}
export default connect(mapStateToProps)(AudioRecording);

const styles = StyleSheet.create({
  content: {
    flexDirection: 'row',
    marginTop: 20,
    backgroundColor: colors.color_blue,
    alignItems: 'center',
    marginEnd: '10%',
    borderRadius: 20,
    padding: 20,
  },
  buttonRecord: {
    backgroundColor: colors.color_orange_4,
    width: 70,
    height: 70,
    borderRadius: 35,
    alignItems: 'center',
    justifyContent: 'center',
  },
  settingsContainer: {
    alignItems: 'center',
  },
  container: {
    borderRadius: 4,
    borderWidth: 0.5,
    borderColor: '#d6d7da',
  },
  title: {
    fontSize: 16,
    textAlign: 'center',
    color: 'white',
    marginTop: 6,
  },
  errorMessage: {
    fontSize: 15,
    textAlign: 'center',
    padding: 10,
    color: 'red',
  },
  viewSlide: {
    flex: 1,
    marginStart: 20,
  },
  btnPlay: {
    alignSelf: 'center',
    // alignItems: 'center',
    // justifyContent: 'center',
  },
  btnControl: {
    width: 40,
    height: 40,
  },
});
