import React from 'react';
import {
  StyleSheet,
  TouchableOpacity,
  Image,
  Dimensions,
  FlatList,
  View,
} from 'react-native';
import {onConfigurations} from '../../common/helper';
import {color_orange} from '../../assets/colors';

import AntDesign from 'react-native-vector-icons/AntDesign';
AntDesign.loadFont();

export default (props) => {
  const {data, item_question, dispatch, user_answer, isFinish, audio} = props;

  const existed = user_answer.find((ob) => ob.question_id === item_question.id);

  data.map((item) => {
    if (!existed) {
      item.selected = false;
    } else {
      if (item.value === existed.user_answer.value) {
        item.selected = true;
      } else {
        item.selected = false;
      }
    }
    return item;
  });

  const renderItem = ({item, index}) => {
    const items = item;
    return (
      <View style={styles.container}>
        <TouchableOpacity
          disabled={isFinish}
          onPress={() => {
            audio();
            onConfigurations({...item_question, items}, user_answer, dispatch);
          }}
          style={[styles.configView]}>
          <Image
            style={[styles.image, item.selected && styles.imgSelected]}
            source={{uri: item.data.value}}
            resizeMode="contain"
          />
        </TouchableOpacity>
        {item.correct === 1 && isFinish && (
          <AntDesign
            name="checkcircle"
            style={{fontSize: 30, color: 'green'}}
          />
        )}
        {item.correct === 0 && isFinish && (
          <AntDesign name="closecircleo" style={{fontSize: 30, color: 'red'}} />
        )}
      </View>
    );
  };

  return (
    <View>
      <FlatList
        data={data}
        numColumns={2}
        renderItem={renderItem}
        keyExtractor={(item, index) => index.toString()}
      />
    </View>
  );
};

const width = Dimensions.get('screen').width;
const widthContent = width / 3.5;
const height = Dimensions.get('screen').height;
const heightImage = height / 3.5;

const styles = StyleSheet.create({
  container: {
    width: widthContent,
    flexDirection: 'row',
    alignItems: 'center',
    marginVertical: 10,
  },
  configView: {
    width: heightImage,
    marginVertical: '2%',
    alignItems: 'center',
    marginHorizontal: 20,
    overflow: 'hidden',
  },
  imgSelected: {
    borderWidth: 4,
    borderColor: color_orange,
    borderRadius: 20,
  },
  image: {
    width: heightImage,
    height: heightImage,
  },
});
