import React, {useState} from 'react';
import {Text, TouchableOpacity, View, Image} from 'react-native';
import {styles} from './styles';
import {arrSTT} from '../../common/constant';
import Slider from '@react-native-community/slider';
import AntDesign from 'react-native-vector-icons/AntDesign';
AntDesign.loadFont();
import ic_play_record from '../../assets/images/ic_play_record.png';
import ic_pause_record from '../../assets/images/ic_pause_record.png';
import {color_orange} from '../../assets/colors';
import Sound from 'react-native-sound';

export const ItemAudio = (props) => {
  const {item, index, isFinish, onPress} = props;

  const [sound, setSound] = useState(null);
  const [progress, setProgress] = useState(0);
  const [playing, setPlay] = useState(false);

  let timer;

  const playAudio = () => {
    if (sound) {
      sound.release();
    }
    const player = new Sound(item.data.value, null, (error) => {
      if (error) {
        return;
      }
      setSound(player);
      setPlay(true);
      player.play((success) => {
        if (success) {
          setPlay(false);
          setSound(null);
        }
        setProgress(0);
        clearInterval(timer);
      });
    });

    timer = setInterval(() => {
      if (player) {
        player.getCurrentTime((seconds) => {
          setProgress(seconds / player.getDuration());
        });
      }
    }, 100);
  };

  const pauseAudio = () => {
    if (!sound) {
      return;
    }
    setPlay(false);
    sound.pause();
  };

  return (
    <View style={styles.container}>
      <TouchableOpacity
        disabled={isFinish}
        activeOpacity={0.5}
        onPress={() => onPress()}
        style={styles.configView}>
        <Text style={[styles.txtABC, item.selected && styles.selected]}>
          {arrSTT[index]}
        </Text>
        <View style={styles.viewAudio}>
          <TouchableOpacity
            disabled={isFinish}
            onPress={!playing ? playAudio : pauseAudio}>
            <Image
              source={!playing ? ic_play_record : ic_pause_record}
              style={styles.imgAudio}
            />
          </TouchableOpacity>
          <Slider
            step={0.0001}
            disabled={true}
            value={progress}
            minimumTrackTintColor={color_orange}
            maximumTrackTintColor="#FFFFFF"
            style={{flex: 1, marginHorizontal: 10}}
          />
        </View>
      </TouchableOpacity>
      {isFinish && item.correct === 1 && (
        <AntDesign name="checkcircle" style={styles.imgTrue} />
      )}
      {isFinish && item.correct === 0 && (
        <AntDesign name="closecircleo" style={styles.imgFalse} />
      )}
    </View>
  );
};
