/* eslint-disable react-hooks/exhaustive-deps */
import React, {useEffect, useState} from 'react';
import {
  TouchableOpacity,
  View,
  Text,
  SafeAreaView,
  Image,
  ActivityIndicator,
  Alert,
} from 'react-native';

import {useDispatch, useSelector} from 'react-redux';
import SharePreference from '../../common/SharePreference';
import * as actions from '../../redux/actions';
import {createSelector} from 'reselect';
import AntDesign from 'react-native-vector-icons/AntDesign';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import MaterialIcons from 'react-native-vector-icons/MaterialIcons';
// import logo from '../../assets/images/logo.png';
// import ic_tutorial from '../../assets/images/ic_tutorial.png';
import ic_clock_orange from '../../assets/images/ic_clock_orange.png';
import ic_question from '../../assets/images/ic_question.png';
import DownloadAudio from '../start/view/download-sound';
import {styles} from './styles';
import {hideCotrolAndroid} from '../../common/helper';
import dayjs from 'dayjs';

AntDesign.loadFont();
FontAwesome.loadFont();
MaterialIcons.loadFont();

const getData = createSelector(
  (state) => state.reducersAccepted,
  (reducersAccepted) => reducersAccepted,
);

let downloadAudio;

export default (props) => {
  const {navigation, route} = props;
  const dispatch = useDispatch();
  const {data, error} = useSelector(getData);
  const [loading, setLoading] = useState(false);
  const {isFinish, isResult, token, student_id, domain} = route.params;

  useEffect(() => {
    hideCotrolAndroid();
    if (route.params?.linkUrl) {
      getInfoFromUrl(route.params.linkUrl);
    } else {
      // getInfoFromUrl(fixLinkTest);
    }
  }, []);

  const getInfoFromUrl = (linkQA) => {
    if (linkQA && linkQA.includes('code=')) {
      const arrSplit = linkQA.split('code=');
      if (arrSplit.length > 0) {
        const code = arrSplit[1];
        let domainHotqa = 'test.ekidpro.com';
        const arrSplit2 = linkQA.split('/');
        if (arrSplit2.length > 3) {
          domainHotqa = arrSplit2[2];
        }
        if (arrSplit2.length > 5) {
          if (arrSplit2[5] === 'free') {
            SharePreference.isTest = false;
          } else {
            SharePreference.isTest = true;
          }
        } else {
          SharePreference.isTest = false;
        }
        const auth = {
          device_id: '',
          domain: domainHotqa,
          code: code,
        };
        let param;
        if (isResult) {
          param = {
            auth: domain,
            test_id: arrSplit2[6],
            student_id: student_id,
            token: token,
          };
        } else {
          param = {
            auth: auth,
            test_id: arrSplit2[6],
          };
        }
        dispatch({
          type: actions.REQUEST_IS_RESULT,
          payload: {isResult},
        });
        if (isResult) {
          dispatch({type: actions.REQUEST_SECTION_INFO, payload: param});
        } else {
          dispatch({type: actions.REQUEST_AUTHENCATION, payload: param});
        }
      }
    }
  };

  const download = () => {
    setLoading(true);
    downloadAudio = new DownloadAudio({data: data, start: () => startTest()});
    if (downloadAudio) {
      downloadAudio.getArrLink();
    }
  };

  const startTest = () => {
    setLoading(false);
    dispatch({
      type: actions.REQUEST_IS_FINISH,
      payload: {isFinish},
    });
    SharePreference.startTest = dayjs().unix();
    navigation.replace('Start');
  };

  const backExit = () => {
    hideCotrolAndroid();
    if (downloadAudio) {
      downloadAudio.stopDownload();
    }
    dispatch({type: actions.REQUEST_CLEAR_DATA});
    route.params.nav.goBack();
  };

  if (data == null && !error) {
    return (
      <View style={styles.container}>
        <ActivityIndicator size="large" color="#7d9db5" />
      </View>
    );
  }

  if (error) {
    return (
      <>
        {Alert.alert('', error, [
          {
            text: 'Thoát',
            onPress: () => backExit(),
          },
        ])}
      </>
    );
  }

  return (
    <SafeAreaView style={styles.safe}>
      <View style={styles.content}>
        <Text style={styles.title}>{data.title}</Text>
        <View style={styles.quizView}>
          <View style={styles.viewInfo}>
            <Image
              source={ic_clock_orange}
              resizeMode="contain"
              style={styles.iconClock}
            />
            <Text style={styles.time}>Thời gian: {data.time_limit} phút</Text>
          </View>
          <View style={styles.viewInfo}>
            <Image
              source={ic_question}
              resizeMode="contain"
              style={styles.iconQuestion}
            />
            <Text style={styles.time}>Câu hỏi: {data.total_questions}</Text>
          </View>
        </View>

        <Text style={[styles.textSize30, {color: '#4C51D9'}]}>
          Bạn đã sẵn sàng chưa?
        </Text>

        <TouchableOpacity
          style={styles.button}
          disabled={loading}
          onPress={download}>
          {loading ? (
            <ActivityIndicator size="small" color="#FFF" />
          ) : (
            <Text style={styles.textSize30}>
              {!isFinish ? 'Sẵn sàng' : 'Xem kết quả'}
            </Text>
          )}
        </TouchableOpacity>
      </View>
      <View style={styles.flexView}>
        <TouchableOpacity
          style={styles.btnBack}
          onPress={() => {
            dispatch({type: actions.REQUEST_CLEAR_DATA});
            if (route) {
              route.params?.nav.goBack();
            }
          }}>
          <MaterialIcons name="keyboard-backspace" style={styles.iconBack} />
        </TouchableOpacity>
        {/* <TouchableOpacity style={styles.btnTutorial}>
          <Image
            style={styles.iconTutorial}
            source={ic_tutorial}
            resizeMode="contain"
          />
        </TouchableOpacity> */}
      </View>
    </SafeAreaView>
  );
};
