import React, {useState, useEffect} from 'react';
import {
  View,
  Text,
  Image,
  ActivityIndicator,
  useWindowDimensions,
} from 'react-native';
import Swiper from '../../../components/swiper';
import Icon from 'react-native-vector-icons/Ionicons';
import {createSelector} from 'reselect';
import {useDispatch, useSelector} from 'react-redux';
import _ from 'lodash';

import SingleChoice from '../../../components/single-choice';
import MultipleChoice from '../../../components/multiple-choice';
import ImageChoice from '../../../components/image-choice';
import Writing from '../../../components/writing';
import AudioRecording from '../../../components/audio-recording';
import Reorder from '../../../components/reorder/index2';
import Matching from '../../../components/matching';
import FillInTheBlank from '../../../components/fill-in-the-blank';
import FillInTheBlankWiring from '../../../components/fill-in-the-blank-writing';

import * as TYPE from '../../../common/constant';
import {onConfigurations} from '../../../common/helper';
import HTMLView from 'react-native-htmlview';
import {styles} from './style';
import SoundManager from '../../../components/SoundManager';
import {dataQuestion, getFileName} from './data-question';
import {Player} from '../../../components/player.js';
import Video from 'react-native-video';

Icon.loadFont();
const getData = createSelector(
  (state) => state.reducersAccepted,
  (reducersAccepted) => reducersAccepted,
);

const getKey = createSelector(
  (state) => state.reducerComponents,
  (reducerComponents) => reducerComponents,
);
const getUserAnswer = createSelector(
  (state) => state.submitData,
  (submitData) => submitData,
);

export default (props) => {
  const {navigation, route} = props;
  const dispatch = useDispatch();
  const [isChoose, setChoose] = useState(false);
  const {data, loading, error} = useSelector(getData);
  const {keyPage, isFinish, isResult} = useSelector(getKey);
  const {user_answer: answers} = useSelector(getUserAnswer);
  const [questions, setQuestions] = useState(null);
  const [isRecording, setRecording] = useState(false);
  const refPlay = React.useRef(null);

  const {width} = useWindowDimensions();

  let limitMedia = 10;

  let user_answer = answers;

  useEffect(() => {
    convertData();
    getLimitPlay();
  }, []);

  const convertData = () => {
    if (data) {
      const arrQuestions = dataQuestion(data, isResult, dispatch);
      user_answer = arrQuestions[0];
      setQuestions(arrQuestions[1]);
    }
  };

  const getLimitPlay = () => {
    if (data && data.extra) {
      const parseExtra = JSON.parse(data.extra);
      if (parseExtra.media) {
        const {limit_play} = parseExtra.media;
        if (limit_play > 0) {
          limitMedia = limit_play;
        }
      }
    }
  };

  const getPath = (item) => {
    const name = getFileName(item.value);
    return `${TYPE.FOLDER_SOUND}/${name}`;
  };

  const playAudio = (item, index) => {
    if (!isChoose) {
      const path = getPath(item);
      const sound = SoundManager.play(item.value, path);
      if (sound) {
        sound.play(() => {
          if (refPlay.current) {
            refPlay.current.onPlayComplete();
          }
          limitMedia = limitMedia - 1;
        });
      }
    }
  };

  let matchingSound;
  let itemFocus;
  const stopAudio = () => {
    if (itemFocus) {
      const path = getPath(itemFocus);
      SoundManager.stop(path);
    }
  };

  const contentText = (item) => {
    let content = item.value;
    if (item.rawHtml) {
      content = item.rawHtml;
      content = _.replace(item.rawHtml, new RegExp('\n<p>', 'g'), '<p>');
      // content = _.replace(content, new RegExp('</p>', 'g'), '');
    }
    return content;
  };

  const viewTitle = (item, i) => {
    switch (item.type) {
      case 'image':
        return <Image source={{uri: item.value}} style={styles.imgQuestion} />;
      case 'text':
        // return <Text style={styles.outline}>{item.value}</Text>;
        return (
          <HTMLView value={contentText(item)} style={{marginBottom: 10}} />
        );
      case 'audio':
        if (keyPage === i) {
          playAudio(item, i);
          itemFocus = item;

          return (
            <Player
              ref={refPlay}
              action={(isPlay) => {
                if (isChoose) {
                  setChoose(false);
                }
                const path = getPath(item);
                if (isPlay) {
                  SoundManager.pause(path);
                } else {
                  playAudio(item, i);
                }
              }}
            />
          );
        } else {
          return;
        }

      case 'video': {
        return (
          <Video
            source={{uri: item.value}}
            repeat={true}
            style={{width: width * 0.3, height: (width * 0.3 * 3) / 4}}
          />
        );
      }
    }
  };

  if (!data) {
    return <View />;
  }

  return (
    <View style={styles.safe}>
      {questions ? (
        <Swiper
          isRecording={isRecording}
          questions={questions}
          navigation={navigation}
          stopSound={() => {
            if (matchingSound) {
              matchingSound.stop();
            }
            setChoose(false);
            stopAudio();
          }}
          keyPage={keyPage}
          route={route.params?.nav}>
          {questions.map((item, i) => {
            const extra =
              JSON.parse(item.extra) === null ? [] : JSON.parse(item.extra);
            const configurations = JSON.parse(item.configurations);

            const type = item.type;
            const {outline, outline_s} = item;
            // console.log(166, i, item);
            return (
              <View style={[styles.slide]} key={i}>
                {(outline_s ||
                  outline ||
                  (extra !== null && extra.length > 0)) && (
                  <View style={styles.viewOutline}>
                    {outline_s ? (
                      <HTMLView
                        value={outline_s}
                        style={{marginHorizontal: 20}}
                      />
                    ) : null}
                    {outline ? (
                      <HTMLView
                        value={outline}
                        style={{marginHorizontal: 20}}
                      />
                    ) : null}
                    {extra.length > 0 && (
                      <View style={styles.viewTitle}>
                        {/* {viewTitle(extra)} */}
                        {extra[0] && viewTitle(extra[0], i)}
                        {extra[1] && viewTitle(extra[1], i)}
                      </View>
                    )}
                  </View>
                )}
                <View style={{flex: 0.6}}>
                  <Text style={styles.title}>{item.title}</Text>
                  <View style={{marginTop: 10}}>
                    {type === TYPE.SINGLE_CHOICE &&
                      item.configurations_type !== 'image' && (
                        <SingleChoice
                          data={configurations}
                          item_question={item}
                          user_answer={user_answer}
                          onPress={(items) => {
                            setChoose(true);
                            onConfigurations(
                              {...item, items},
                              user_answer,
                              dispatch,
                            );
                          }}
                          keyPage={keyPage}
                          index={i}
                          isFinish={isFinish}
                        />
                      )}

                    {type === TYPE.MULTIPLE_CHOICE &&
                      item.configurations_type !== 'image' && (
                        <MultipleChoice
                          onPress={(items) => {
                            setChoose(true);
                            onConfigurations(
                              {...item, items},
                              user_answer,
                              dispatch,
                            );
                          }}
                          data={configurations}
                          item_question={item}
                          user_answer={user_answer}
                          keyPage={keyPage}
                          index={i}
                          isFinish={isFinish}
                        />
                      )}

                    {item.configurations_type === 'image' && (
                      <ImageChoice
                        data={configurations}
                        type={type}
                        dispatch={dispatch}
                        user_answer={user_answer}
                        item_question={item}
                        keyPage={keyPage}
                        index={i}
                        isFinish={isFinish}
                        audio={() => {
                          setChoose(true);
                          // stopAudio();
                        }}
                      />
                    )}
                    {type === TYPE.WRITING && (
                      <Writing
                        item={item}
                        user_answer={user_answer}
                        dispatch={dispatch}
                        isFinish={isFinish}
                        audio={() => {
                          stopAudio();
                        }}
                      />
                    )}
                    {type === TYPE.REORDER && (
                      <Reorder
                        item={item}
                        dispatch={dispatch}
                        isFinish={isFinish}
                        user_answer={user_answer}
                      />
                    )}
                    {type === TYPE.MATCHING && (
                      <Matching
                        item={item}
                        dispatch={dispatch}
                        pSound={(res) => (matchingSound = res)}
                        isFinish={isFinish}
                        isResult={isResult}
                        user_answer={user_answer}
                      />
                    )}
                    {type === TYPE.FILL_IN_THE_BLANK && (
                      <FillInTheBlank
                        item={item}
                        dispatch={dispatch}
                        isFinish={isFinish}
                        user_answer={user_answer}
                        audio={() => {
                          stopAudio();
                        }}
                      />
                    )}
                    {type === TYPE.FILL_IN_THE_BLANK_WRITING && (
                      <FillInTheBlankWiring
                        item={item}
                        dispatch={dispatch}
                        isFinish={isFinish}
                        user_answer={user_answer}
                        audio={() => {
                          stopAudio();
                        }}
                      />
                    )}
                    {type === TYPE.AUDIO_RECORDING && (
                      <AudioRecording
                        item={item}
                        onPauseAudio={(recording) => {
                          setRecording(recording);
                          stopAudio();
                        }}
                        user_answer={user_answer}
                        isFinish={isFinish}
                      />
                    )}
                  </View>
                </View>
              </View>
            );
          })}
        </Swiper>
      ) : (
        <View style={styles.container}>
          <ActivityIndicator
            size="large"
            color="#7d9db5"
            style={styles.indicator}
          />
        </View>
      )}
    </View>
  );
};
