import {applyMiddleware, createStore, combineReducers} from 'redux';
import {createLogger} from 'redux-logger';
import {rootReducer} from './reducers';
import {persistStore} from 'redux-persist';
import createSagaMiddleware from 'redux-saga';

const logger = createLogger({
  predicate: (getState, action) =>
    action.type !== 'PIXI_UPDATE_MOUSE_POISITION',
  collapsed: (getState, action, logEntry) => !logEntry.error,
});

const sagaMiddleware = createSagaMiddleware();
let middlewares = [sagaMiddleware];
if (process.env.NODE_ENV === 'development') {
  middlewares.push(logger);
}
const createReducer = (asyncReducers) => {
  const appReducer = combineReducers({
    ...rootReducer,
    ...asyncReducers,
  });

  return (state, action) => {
    // const {type} = action;
    // // TODO: fix-me; do not use the string AUTH_LOG_OUT, change it to variables
    // if (type === 'AUTH_LOG_OUT') {
    //   state = undefined
    // }

    return appReducer(state, action);
  };
};
const configureStore = () => {
  const store = createStore(createReducer(), applyMiddleware(...middlewares));

  store.asyncReducers = {};

  store.injectReducer = (key, asyncReducer) => {
    store.asyncReducers[key] = asyncReducer;
    store.replaceReducer(createReducer(store.asyncReducers));
    store.persistor.persist();
  };

  return store;
};

export const saga = sagaMiddleware.run;
export const store = configureStore();
export const persistor = persistStore(store);

// Add back to store to use with injection
store.persistor = persistor;

export default {store};
