import SharePreference from '../../common/SharePreference';
import * as actions from '../actions';

export const initialState = {
  loading: null,
  data: null,
  error: null,
  info: null,
};

export default (state = initialState, action) => {
  const {type, payload} = action;
  switch (type) {
    case actions.REQUEST_DATA_QUESTIONS_LOADING: {
      return {
        ...state,
        loading: true,
      };
    }
    case actions.REQUEST_DATA_QUESTIONS_SUCCESS: {
      const {data} = payload;
      console.log(29, data);
      let convertData;
      if (SharePreference.isTest) {
        convertData = data.test_data;
        convertData.user_test_id = data.id;
        convertData.examinee_name = data.examinee_name;
      } else {
        convertData = data;
      }

      return {
        ...state,
        loading: false,
        data: convertData,
      };
    }
    case actions.REQUEST_DATA_QUESTIONS_FAIL: {
      let {message} = payload;
      message = JSON.parse(message);

      return {
        ...state,
        loading: false,
        error: message.message,
      };
    }
    case actions.REQUEST_CLEAR_DATA: {
      return {
        loading: null,
        data: null,
        error: null,
        info: null,
      };
    }
    // truong hop xem lai ket qua cua bai quiz
    case actions.REQUEST_SECTION_INFO_SUCCESS: {
      const {data} = payload;
      console.log('REQUEST_SECTION_INFO_SUCCESS', data);
      if (data) {
        return {
          ...state,
          info: data,
        };
      } else {
        return {
          ...state,
        };
      }
    }
    case actions.REQUEST_RESULT_TEST_SUCCESS: {
      const {data} = payload;
      // console.log(65, data);
      const {info} = state;
      if (!info) {
        return {...state, error: 'Chưa có kết quả bài test'};
      }
      const mergeData = info.test_data;
      mergeData.total_questions = info.total_questions;
      mergeData.examinee_name = info.examinee_name;
      mergeData.sections = data;
      console.log('REQUEST_RESULT_TEST_SUCCESS', mergeData);
      return {
        ...state,
        loading: false,
        data: mergeData,
      };
    }
    case actions.REQUEST_SECTION_INFO_FAIL: {
      let {message} = payload;
      message = JSON.parse(message);

      return {
        ...state,
        loading: false,
        error: message.message,
      };
    }

    default:
      return state;
  }
};
