/* eslint-disable no-dupe-keys */
import {all, call, put, takeEvery, takeLatest} from 'redux-saga/effects';
import SharePreference from '../../common/SharePreference';
import Config from '../../Config';
import * as actions from '../actions';
import {request} from '../api';
import {saga} from '../index';
import {watchAPIAnswer} from './upload.saga';

function* getAPIAuthen(action) {
  const {payload} = action;

  try {
    // yield put({type: actions.REQUEST_DATA_QUESTIONS_LOADING, payload: {}});
    const getDataAuthen = yield call(request, {
      url: `${Config.url}/api/auth`,
      method: 'post',
      body: payload.auth,
    });
    const {body} = getDataAuthen;
    SharePreference.token_hotqa = `Bearer ${body.access_token}`;

    yield put({
      type: actions.REQUEST_DATA_QUESTIONS,
      payload: {test_id: payload.test_id},
    });
  } catch (e) {
    yield put({
      type: actions.REQUEST_DATA_QUESTIONS_FAIL,
      payload: {message: e.message},
    });
  }
}

function* watchAPIAuthen() {
  yield takeLatest(actions.REQUEST_AUTHENCATION, getAPIAuthen);
}

function* getAPIQuestion(action) {
  const {payload} = action;

  try {
    // yield put({type: actions.REQUEST_DATA_QUESTIONS_LOADING, payload: {}});
    const url = SharePreference.isTest
      ? `${Config.url}/api/user-test/questions/${payload.test_id}`
      : `${Config.url}/api/test/questions/${payload.test_id}`;
    const getQuestions = yield call(request, {
      url: url,
      method: 'get',
      headers: {Authorization: SharePreference.token_hotqa},
    });

    yield put({
      type: actions.REQUEST_DATA_QUESTIONS_SUCCESS,
      payload: {data: getQuestions.body.data},
    });
  } catch (e) {
    yield put({
      type: actions.REQUEST_DATA_QUESTIONS_FAIL,
      payload: {message: e.message},
    });
  }
}

function* watchAPIAccepted() {
  yield takeLatest(actions.REQUEST_DATA_QUESTIONS, getAPIQuestion);
}

function* uploadFile(action) {
  const {payload} = action;

  try {
    // yield put({type: actions.REQUEST_DATA_QUESTIONS_LOADING, payload: {}});
    const getUpload = yield call(request, {
      url: `${Config.url}/api/uploads`,
      method: 'post',
      headers: {Authorization: SharePreference.token_hotqa},
      body: payload,
    });
    payload.user_answer.value = getUpload.body.data;
    yield put({
      type: actions.REQUEST_UPLOAD_RECORD_SUCCESS,
      payload: {data: getUpload.body.data},
    });
    yield put({
      type: actions.REQUEST_SUBMIT_USES_ANSWER,
      payload: {data: payload},
    });
  } catch (e) {
    yield put({
      type: actions.REQUEST_UPLOAD_RECORD_FAIL,
      payload: {message: e.message},
    });
  }
}

function* watchAPIUpload() {
  yield takeLatest(actions.REQUEST_UPLOAD_RECORD, uploadFile);
}

function* getResult(action) {
  const {payload} = action;
  const {auth, test_id, student_id, token} = payload;

  try {
    const result = yield call(request, {
      url: `${auth}/api/v2/students/${student_id}/test/${test_id}/sections`,
      method: 'get',
      headers: {Authorization: token},
    });
    const {body} = result;
    // console.log(113, body);
    yield put({
      type: actions.REQUEST_RESULT_TEST_SUCCESS,
      payload: {data: body.data},
    });
  } catch (e) {
    yield put({
      type: actions.REQUEST_RESULT_TEST_FAIL,
      payload: {message: e.message},
    });
  }
}

function* watchAPIResult() {
  yield takeLatest(actions.REQUEST_RESULT_TEST, getResult);
}

function* getSectionInfo(action) {
  const {payload} = action;
  const {auth, test_id, student_id, token} = payload;

  try {
    const result = yield call(request, {
      url: `${auth}/api/v2/students/${student_id}/test/${test_id}/statistics`,
      method: 'get',
      headers: {Authorization: token},
    });
    const {body} = result;
    // console.log(140, body);
    yield put({
      type: actions.REQUEST_SECTION_INFO_SUCCESS,
      payload: {data: body.data},
    });
    yield put({
      type: actions.REQUEST_RESULT_TEST,
      payload: payload,
    });
  } catch (e) {
    yield put({
      type: actions.REQUEST_SECTION_INFO_FAIL,
      payload: {message: e.message},
    });
  }
}

function* watchAPISectionInfo() {
  yield takeLatest(actions.REQUEST_SECTION_INFO, getSectionInfo);
}

function* rootSaga() {
  yield all([
    watchAPIAuthen(),
    watchAPIAccepted(),
    watchAPIUpload(),
    watchAPIAnswer(),
    watchAPIResult(),
    watchAPISectionInfo(),
  ]);
}

saga(rootSaga);
